@@ -6,7 +6,7 @@
 # Author: jianglin
 # Email: mail@honmaple.com
 # Created: 2018-02-26 11:44:43 (CST)
-# Last Update: Tuesday 2020-08-18 02:14:37 (CST)
+# Last Update: Tuesday 2020-08-18 02:27:13 (CST)
 # Description:
 # ********************************************************************************
 import re
@@ -320,7 +320,7 @@ class Headline(Parser):
 
         for tag in self.tags:
             b = b + "<span class=\"tag\">{0}</span>".format(tag)
-        return b
+        return b.strip()
 
     def to_html(self):
         b = "<h{0} id=\"{1}\">{2}</h{0}>".format(
@@ -770,7 +770,7 @@ class Section(Parser):
 
     def to_html(self):
         text = "<li>"
-        text += "<a href=\"{0}\">{1}</a>".format(
+        text += "<a href=\"#{0}\">{1}</a>".format(
             self.headline.id(),
             self.headline.toc(),
         )
